# Installation

## Installation with pip

Datahugger requires Python 3.6 or later.

```
pip install datahugger
```

## Upgrade


```
pip install --upgrade datahugger
```

## Extra dependencies

To download datasets from some repositories, you need addition requirements.
When a service requires more dependencies, the installation instructions are
given.

To download all dependencies, use

```
pip install datahugger[all]
```
